Enum Event

#[non_exhaustive]
pub enum Event { Release, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Release

compositor releases buffer

Sent when this wl_buffer is no longer used by the compositor.

For more information on when release events may or may not be sent, and what consequences it has, please see the description of wl_surface.attach.

If a client receives a release event before the frame callback requested in the same wl_surface.commit that attaches this wl_buffer to a surface, then the client is immediately free to reuse the buffer and its backing storage, and does not need a second buffer for the next surface content update. Typically this is possible, when the compositor maintains a copy of the wl_surface contents, e.g. as a GL texture. This is an important optimization for GL(ES) compositors with wl_shm clients.

Implementations



impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message